summaryrefslogtreecommitdiff
path: root/framework
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2019-09-02 20:17:40 +0200
committerJulien Nabet <serval2412@yahoo.fr>2019-09-03 10:31:49 +0200
commit602c6097850d6d659b760bdb0dd83baa906d416c (patch)
tree2c2b6ba0fdfd17825774dbe27bb267159a5c6b26 /framework
parenteced5a20b5db1364aa9feb50dfc8e55b34324b9e (diff)
Fix typos
Change-Id: I71bacf86938af2b89a706c435c4f72a194ec8343 Reviewed-on: https://gerrit.libreoffice.org/78417 Reviewed-by: Julien Nabet <serval2412@yahoo.fr> Tested-by: Julien Nabet <serval2412@yahoo.fr>
Diffstat (limited to 'framework')
-rw-r--r--framework/source/jobs/jobdata.cxx2
-rw-r--r--framework/source/loadenv/loadenv.cxx2
-rw-r--r--framework/source/services/autorecovery.cxx6
3 files changed, 5 insertions, 5 deletions
diff --git a/framework/source/jobs/jobdata.cxx b/framework/source/jobs/jobdata.cxx
index 5d51c97bdeaa..fa22465e2b65 100644
--- a/framework/source/jobs/jobdata.cxx
+++ b/framework/source/jobs/jobdata.cxx
@@ -190,7 +190,7 @@ void JobData::setService( const OUString& sService )
Because the caller must have the configuration already open to
get the values for sEvent and sAlias! And doing so it can perform
only, if the time stamp values are read outside too.
- Further it make no sense to initialize and start a disabled job.
+ Further it makes no sense to initialize and start a disabled job.
So this initialization method will be called for enabled jobs only.)
@param sEvent
diff --git a/framework/source/loadenv/loadenv.cxx b/framework/source/loadenv/loadenv.cxx
index 73180facd46a..119f7d22ffcc 100644
--- a/framework/source/loadenv/loadenv.cxx
+++ b/framework/source/loadenv/loadenv.cxx
@@ -554,7 +554,7 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
// load request will fail.
/* Attention: The following code can't work on such special URLs!
- It should not break the office .. but it make no sense
+ It should not break the office .. but it makes no sense
to start expensive object creations and complex search
algorithm if its clear, that such URLs must be handled
in a special way .-)
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index 7f2ad1f931ee..625739ec4cfe 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -638,7 +638,7 @@ private:
@param bStopListening
sal_False: must be used in case this method is called within disposing() of the document,
- where it make no sense to deregister our listener. The container dies...
+ where it makes no sense to deregister our listener. The container dies...
sal_True : must be used in case this method is used on "deregistration" of this document, where
we must deregister our listener .-)
@@ -1371,7 +1371,7 @@ void AutoRecovery::implts_dispatch(const DispatchParams& aParams)
bool bWasUserAutoSaveActive =
((eJob & AutoRecovery::E_USER_AUTO_SAVE) == AutoRecovery::E_USER_AUTO_SAVE);
// On the other side it make no sense to reactivate the AutoSave operation
// if the new dispatch indicates a final decision ...
// E.g. an EmergencySave/SessionSave indicates the end of life of the current office session.
// It make no sense to reactivate an AutoSave then.
@@ -2515,7 +2515,7 @@ void AutoRecovery::implts_deregisterDocument(const css::uno::Reference< css::fra
} /* SAFE */
/* This method is called within disposing() of the document too. But there it's not a good idea to
- deregister us as listener. Further it make no sense - because the broadcaster dies.
+ deregister us as listener. Further it makes no sense - because the broadcaster dies.
So we suppress deregistration in such case...
*/
if (bStopListening)
@@ -1371,7 +1371,7 @@ void AutoRecovery::implts_dispatch(const DispatchParams& aParams)
bool bWasUserAutoSaveActive =
((eJob & AutoRecovery::E_USER_AUTO_SAVE) == AutoRecovery::E_USER_AUTO_SAVE);
- // On the other side it make no sense to reactivate the AutoSave operation
+ // On the other side it makes no sense to reactivate the AutoSave operation
// if the new dispatch indicates a final decision ...
// E.g. an EmergencySave/SessionSave indicates the end of life of the current office session.